| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Data.Time.LocalTime.TimeZone.Unix
Description
UNIX-specific handling of time data.
Synopsis
- getCurrentTimeZoneSeries :: IO TimeZoneSeries
- getTimeZoneSeriesForZone :: Maybe TimeZoneSpec -> IO TimeZoneSeries
- type CountryCode = String
- getCountryCodes :: IO [(CountryCode, String)]
- type TimeZoneSpec = String
- data ZoneDescription = MkZoneDescription {
- zoneCountries :: [CountryCode]
- zoneLocation :: (Rational, Rational, Bool)
- zoneName :: TimeZoneSpec
- zoneComment :: String
- getZoneDescriptions :: IO [ZoneDescription]
- getCurrentOlsonData :: IO OlsonData
- getOlsonDataForZone :: Maybe TimeZoneSpec -> IO OlsonData
- getLeapSecondList :: IO LeapSecondList
Time Zone
getCurrentTimeZoneSeries :: IO TimeZoneSeries Source #
Get the current TimeZoneSeries (as specifed by TZ env-var or else the system default).
getTimeZoneSeriesForZone :: Maybe TimeZoneSpec -> IO TimeZoneSeries Source #
Get the TimeZoneSeries for this TimeZoneSpec (or for the system default), defaulting to UTC if the name is not found.
Country Information
type CountryCode = String Source #
ISO 3166 alpha-2 country code (i.e., two capital letters).
getCountryCodes :: IO [(CountryCode, String)] Source #
Get the country codes and names found in iso3166.tab.
Note that earlier versions of zoneinfo don't include this file, in which case this will throw exception matching isDoesNotExistError.
Zone Information
type TimeZoneSpec = String Source #
Time-zone specification as used in the TZ environment variable, e.g. "America/Los_Angeles".
data ZoneDescription Source #
Information about a zone.
Constructors
| MkZoneDescription | |
Fields
| |
getZoneDescriptions :: IO [ZoneDescription] Source #
Get the zone descriptions found in zone1970.tab (or zone.tab).
OlsonData
getCurrentOlsonData :: IO OlsonData Source #
Get the current OlsonData (as specifed by TZ env-var or else the system default).
getOlsonDataForZone :: Maybe TimeZoneSpec -> IO OlsonData Source #
Obtain an OlsonData file for this TimeZoneSpec (or for the system default).
If the file is not in the database, return an empty OlsonData with the name in olsonPosixTZ.
Leap Seconds
getLeapSecondList :: IO LeapSecondList Source #
Get the leap-second list found in leap-seconds.list.
Note that earlier versions of zoneinfo don't include this file, in which case this will throw exception matching isDoesNotExistError.